@@ -517,14 +517,15 @@ OC.L10N.register(
     "Failed" : "C'hwitet",
     "OK" : "OK",
     "Confirm" : "Kadarnañ",
-    "Back" : "Distro",
     "Cancel" : "Nullañ",
+    "Back" : "Distro",
     "Calendar" : "Deiziataer",
     "Save" : "Enrollañ",
     "Search participants" : "Klask implijer",
     "No results" : "Disoc'h ebet",
     "Done" : "Graet",
     "Grid view" : "Diskwell ar roued",
+    "Reload" : "Adkargañ",
     "Waiting for others to join the call …" : "O c'hortoz ma teuio ar re all er gemenadenn ...",
     "You can invite others in the participant tab of the sidebar" : "Galout a rit kouviañ tud gant an daolenn lodek er verenn gostez",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galout a rit kouviañ tud en dolenn lodek er varenn gostez pe rannañ al liamm-mañ evit kouviañ anezho !",
@@ -554,9 +555,9 @@ OC.L10N.register(
     "Choose" : "Dibab",
     "Conversation settings" : "Stummoù diviz",
     "Personal" : "Personel",
-    "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da zilemel  \"{displayName}\"?",
     "Leave conversation" : "Kuitaat an diviz",
     "Delete conversation" : "Dilemel an diviz",
+    "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da zilemel  \"{displayName}\"?",
     "Password protection" : "Gwareziñ gant ur ger-tremen",
     "Start time (optional)" : "Amzer kregiñ (dibab)",
     "Edit" : "Cheñch",
@@ -631,8 +632,9 @@ OC.L10N.register(
     "Select conversation" : "Choaz un diviz",
     "Select location for attachments" : "Choazit ul lec'h evit stagañ",
     "Error while setting attachment folder" : "Ur fazi a zo bet en ur lakaat an teuliad stagañ",
-    "Attachments folder" : "Teuliad stag",
+    "Notification settings" : "Arventennoù kemennadennoù",
     "Privacy" : "Prevezder",
+    "Attachments folder" : "Teuliad stag",
     "Search" : "Klask",
     "Start call" : "Kregiñ ar gemenadenn",
     "You will be able to join the call only after a moderator starts it." : "Posupl vo deoc'h mont er gemenadenn goude ma vo bet groget gant ar modertator.",
@@ -684,8 +686,6 @@ OC.L10N.register(
     "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
     "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
     "Lost connection to signaling server. Trying to reconnect." : "Kenstagadenn gant ar servijour arhent kollet. O klask adkemprenn.",
-    "Establishing signaling connection is taking longer than expected …" : "Lakaat an arhent kenstagañ a zo hiroc'h eget gortozet ...",
-    "Failed to establish signaling connection. Retrying …" : "C'hwitet da lakaat an arhent kemprenn. O klask en dro ...",
     "Please reload the page." : "Mar-plij adkargit ar bajenn",
     "Do not disturb" : "Na rannit ket",
     "Away" : "Pell",
@@ -718,6 +718,8 @@ OC.L10N.register(
     "Choose devices" : "Choazit un ardivink",
     "Sharing your screen only works with Firefox version 52 or newer." : "Rannañ  ho skramm a dro nmetken gant  Firefox stumm 52 pe nevezoc'h.",
     "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm."
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm.",
+    "Establishing signaling connection is taking longer than expected …" : "Lakaat an arhent kenstagañ a zo hiroc'h eget gortozet ...",
+    "Failed to establish signaling connection. Retrying …" : "C'hwitet da lakaat an arhent kemprenn. O klask en dro ..."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
