@@ -64,8 +64,8 @@ OC.L10N.register(
     "Checking …" : "Verificando ...",
     "Confirm" : "Confirmar",
     "Reset" : "Restablecer",
-    "Back" : "Atrás",
     "Cancel" : "Cancelar",
+    "Back" : "Atrás",
     "Calendar" : "Calendario",
     "Attendees" : "Asistentes",
     "Save" : "Guardar",
@@ -107,7 +107,9 @@ OC.L10N.register(
     "No audio" : "Sin audio",
     "Upload" : "Cargar",
     "Files" : "Archivos",
+    "24 hours" : "24 horas",
     "Reply" : "Responder",
+    "More actions" : "Más acciones",
     "Translate" : "Traducir",
     "Dismiss" : "Descartar",
     "Contact" : "Contacto",
@@ -125,9 +127,7 @@ OC.L10N.register(
     "Chat" : "Chat",
     "Details" : "Detalles",
     "Privacy" : "Privacidad",
-    "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
-    "More actions" : "Más acciones",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -164,7 +164,7 @@ OC.L10N.register(
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
-    "Close" : "Cerrar",
+    "Keyboard shortcuts" : "Atajos del teclado",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla."
