@@ -63,6 +63,7 @@ OC.L10N.register(
     "{actor} deleted a message" : "הודעה נמחקה על ידי {actor}",
     "You deleted a message" : "מחקת הודעה",
     "Message deleted by author" : "ההודעה נמחקה על ידי מי שפרסם אותה",
+    "Deleted user" : "משתמש מחוק",
     "Administration" : "ניהול",
     "System" : "מערכת",
     "Talk conversations" : "דיוני שיח",
@@ -403,6 +404,7 @@ OC.L10N.register(
     "Reset" : "איפוס",
     "Cancel" : "ביטול",
     "Back" : "חזרה",
+    "Meeting" : "מפגש",
     "Loading …" : "בטעינה…",
     "From" : "מאת",
     "To" : "אל",
@@ -414,6 +416,7 @@ OC.L10N.register(
     "Done" : "הסתיים",
     "Speaker view" : "תצוגת דובר",
     "Grid view" : "תצוגת טבלה",
+    "Reload" : "טעינה מחדש",
     "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
     "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
@@ -426,6 +429,7 @@ OC.L10N.register(
     "You" : "אני",
     "Show screen" : "הצגת מסך",
     "Collapse" : "קיווץ",
+    "Expand" : "הרחבה",
     "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
     "Favorite" : "סימון כמועדף",
     "Date:" : "בתאריך:",
@@ -435,7 +439,6 @@ OC.L10N.register(
     "Disable" : "השבתה",
     "Choose" : "בחר",
     "Restricted" : "מוגבלת",
-    "Meeting" : "מפגש",
     "Conversation settings" : "הגדרות דיון",
     "Personal" : "אישי",
     "Leave conversation" : "יציאה מהדיון",
@@ -453,6 +456,7 @@ OC.L10N.register(
     "Log content" : "תוכן הרישום",
     "Notifications" : "התראות",
     "Important conversation" : "דיון חשוב",
+    "In {conversation}" : "בתוך {conversation}",
     "Join" : "הצטרף",
     "Error while creating the conversation" : "שגיאה ביצירת הדיון",
     "Create conversation" : "יצירת דיון",
@@ -462,9 +466,12 @@ OC.L10N.register(
     "Mark as unread" : "סימון כלא נקרא",
     "Remove from favorites" : "הסרה מהמועדפים",
     "Add to favorites" : "הוספה למועדפים",
+    "Home" : "בית",
+    "Unread" : "לא נקרא",
     "No matches found" : "לא נמצאו התאמות",
     "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
     "Unread messages" : "הודעות שלא נקראו",
+    "Threads" : "שרשורים",
     "Clear filter" : "מחיקת מסנן",
     "Users" : "משתמשים",
     "Groups" : "קבוצות",
@@ -478,14 +485,17 @@ OC.L10N.register(
     "Invalid path selected" : "הנתיב שנבחר שגוי",
     "Upload" : "העלאה",
     "Files" : "קבצים",
+    "24 hours" : "24 שעות",
     "Reply" : "תגובה",
     "More actions" : "פעולות נוספות",
     "Go to file" : "מעבר לקובץ",
     "Translate" : "תרגום",
+    "React with {emoji}" : "הגיבו עם {emoji}",
     "Dismiss" : "התעלמות",
     "Message sent" : "הודעה נשלחה",
     "Deleting message" : "ההודעה נמחקה",
     "Contact" : "איש/אשת קשר",
+    "_%n reply_::_%n replies_" : ["תגובה אחת","%n תגובות","%n תגובות"],
     "No messages" : "אין הודעות",
     "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
     "Add participants" : "הוספת משתתפים",
@@ -517,6 +527,7 @@ OC.L10N.register(
     "Participants" : "משתתפים",
     "Chat" : "צ׳אט",
     "Details" : "פרטים",
+    "No results found" : "לא נמצאו תוצאות",
     "Load more results" : "לטעון עוד תוצאות",
     "Projects" : "מיזמים",
     "Link to a conversation" : "קישור לדיון",
@@ -528,6 +539,7 @@ OC.L10N.register(
     "Search" : "חיפוש",
     "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
     "Start call" : "התחלת שיחה",
+    "React with {reaction}" : "הגיבו עם {reaction}",
     "Screensharing options" : "אפשרויות שיתוף מסך",
     "Enable screensharing" : "הפעלת שיתוף מסך",
     "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
