@@ -275,11 +275,13 @@ OC.L10N.register(
     "Created at" : "Dibuat saat",
     "Failed" : "Gagal",
     "OK" : "OK",
+    "Federated user" : "Pengguna terfederasi",
     "Confirm" : "Konfirmasi",
     "Reset" : "Setel ulang",
     "Cancel" : "Membatalkan",
     "Back" : "Kembali",
     "Now" : "Sekarang",
+    "Meeting" : "Rapat",
     "Loading …" : "Memuat …",
     "Calendar" : "Kalender",
     "Attendees" : "Peserta",
@@ -287,8 +289,10 @@ OC.L10N.register(
     "No results" : "Tidak ada hasil",
     "Done" : "Selesai",
     "Grid view" : "Tampilan kotak",
+    "Reload" : "Muat ulang",
     "Copy link" : "Salin tautan",
     "None" : "Tidak ada",
+    "You" : "Anda",
     "Collapse" : "Tutup",
     "Expand" : "Perluas",
     "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
@@ -300,7 +304,6 @@ OC.L10N.register(
     "Enable" : "Aktifkan",
     "Choose" : "Pilih",
     "Restricted" : "Terbatas",
-    "Meeting" : "Rapat",
     "Personal" : "Pribadi",
     "_%n hour_::_%n hours_" : ["%n jam"],
     "Password protection" : "Password protection",
@@ -319,12 +322,15 @@ OC.L10N.register(
     "Clear filter" : "Bersihkan filter",
     "Users" : "Pengguna",
     "Groups" : "Grup",
+    "Teams" : "Tim",
     "No search results" : "Tidak ada hasil pencarian",
+    "Devices" : "Perangkat",
     "Invalid path selected" : "Jalur terpilih invalid",
     "Blur" : "Kabur",
     "Upload" : "Unggah",
     "Files" : "Berkas",
     "Reply" : "Balas",
+    "More actions" : "Tindakan lainnya",
     "Translate" : "Terjemahkan",
     "Dismiss" : "Batal",
     "Contact" : "Kontak",
@@ -338,6 +344,7 @@ OC.L10N.register(
     "Remove" : "Hapus",
     "Add users or groups" : "Add users or groups",
     "Integrations" : "Integrasi",
+    "Searching …" : "Mencari …",
     "Search or add participants" : "Cari atau tambah peserta",
     "An error occurred while adding the participants" : "Terjadi kesalahan saat menambahkan peserta",
     "You have new unread messages in the chat." : "Anda memiliki pesan baru yang belum dibaca dalam obrolan.",
@@ -350,6 +357,7 @@ OC.L10N.register(
     "Attachments folder" : "Folder lampiran",
     "Search" : "Cari",
     "Keep" : "Simpan",
+    "Submit" : "Kirim",
     "Join a conversation or start a new one!" : "Gabung dengan percakapan atau mulai yang baru!",
     "Join a conversation or start a new one" : "Gabung dengan percakapan atau mulai yang baru",
     "User" : "Pengguna",
@@ -365,6 +373,7 @@ OC.L10N.register(
     "Show all files" : "Tampilkan semua berkas",
     "Default" : "Bawaan",
     "Group" : "Grup",
+    "Team" : "Tim",
     "Please reload the page." : "Silakan muat ulang halaman.",
     "Do not disturb" : "Jangan diganggu",
     "Away" : "Jauh",
