@@ -399,6 +399,7 @@ OC.L10N.register(
     "Cancel" : "Hætta við",
     "Back" : "Til baka",
     "Now" : "Núna",
+    "Meeting" : "Fundur",
     "Loading …" : "Hleð inn …",
     "From" : "Frá",
     "To" : "Til",
@@ -409,6 +410,7 @@ OC.L10N.register(
     "Done" : "Lokið",
     "Grid view" : "Reitasýn",
     "This conversation is read-only" : "This conversation is read-only",
+    "Reload" : "Endurlesa",
     "Connecting …" : "Tengist ...",
     "Waiting for others to join the call …" : "Bíð eftir að fleiri komi inn í símtalið …",
     "You can invite others in the participant tab of the sidebar" : "Þú getur boðið öðrum að taka þátt af þátttakendaflipa hliðarspjaldsins",
@@ -434,7 +436,6 @@ OC.L10N.register(
     "Choose" : "Velja",
     "The file must be a PNG or JPG" : "Skráin verður að vera PNG eða JPG",
     "Restricted" : "Takmarkað",
-    "Meeting" : "Fundur",
     "Personal" : "Persónulegt",
     "Leave conversation" : "Hætta í samtali",
     "Delete conversation" : "Eyða samtali",
@@ -462,6 +463,7 @@ OC.L10N.register(
     "No matches found" : "Engar samsvaranir fundust",
     "Unread messages" : "Ólesin skilaboð",
     "Clear filter" : "Hreinsa síu",
+    "App settings" : "Stillingar forrits",
     "Users" : "Notendur",
     "Groups" : "Hópar",
     "Teams" : "Teymi",
@@ -476,14 +478,8 @@ OC.L10N.register(
     "Blur" : "Móða",
     "Upload" : "Senda inn",
     "Files" : "Skrár",
-    "Later today – {timeLocale}" : "Síðar í dag – {timeLocale}",
-    "Set reminder for later today" : "Setja áminningu seinna í dag",
-    "Tomorrow – {timeLocale}" : "Á morgun – {timeLocale}",
-    "Set reminder for tomorrow" : "Setja áminningu fyrir morgundaginn",
-    "This weekend – {timeLocale}" : "Þessa helgi – {timeLocale}",
-    "Set reminder for this weekend" : "Setja áminningu fyrir þessa helgi",
-    "Next week – {timeLocale}" : "Í næstu viku – {timeLocale}",
-    "Set reminder for next week" : "Setja áminningu fyrir í næstu viku",
+    "24 hours" : "24 klukkustundir",
+    "7 days" : "7 dagar",
     "Reply" : "Svara",
     "More actions" : "Fleiri aðgerðir",
     "Set reminder" : "Setja áminningu",
@@ -502,17 +498,20 @@ OC.L10N.register(
     "Translate to" : "Þýða yfir á",
     "Translating" : "Þýðing",
     "Copy translated text" : "Afrita þýddan texta",
+    "Send now" : "Senda núna",
     "Message sent" : "Skilaboðin hafa verið send",
     "Contact" : "Tengiliður",
     "{stack} in {board}" : "{stack} á {board}",
     "Poll" : "Poll",
     "No messages" : "Engin skilaboð",
+    "Unpin" : "Losa",
     "Create a new group conversation" : "Create a new group conversation",
     "Add participants" : "Bæta við þátttakanda",
     "Enter password" : "Enter password",
     "Send message" : "Senda skilaboð",
     "File to share" : "Skrá til að deila",
     "Add emoji" : "Bæta við tjáningartákni",
+    "Send later" : "Senda síðar",
     "Share from Files" : "Deila úr skrám",
     "Upload from device" : "Senda inn frá tæki",
     "Create new poll" : "Búa til nýja könnun",
@@ -577,6 +576,10 @@ OC.L10N.register(
     "Group" : "Hópur",
     "Team" : "Teymi",
     "Error while sharing file" : "Villa við deilingu skráar",
+    "Later today – {timeLocale}" : "Síðar í dag – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Á morgun – {timeLocale}",
+    "This weekend – {timeLocale}" : "Þessa helgi – {timeLocale}",
+    "Next week – {timeLocale}" : "Í næstu viku – {timeLocale}",
     "Error while parsing a PROPFIND error" : "Villa við þáttun á PROPFIND-villu",
     "Please reload the page." : "Þú ættir að hlaða síðunni aftur inn.",
     "Do not disturb" : "Ónáðið ekki",
@@ -598,7 +601,10 @@ OC.L10N.register(
     "You were invited to a conversation." : "Þér var boðið að taka þátt í samtali.",
     "Click the button below to join." : "Smelltu á hnappinn hér fyrir neðan til að taka þátt.",
     "Join »%s«" : "Taka þátt í »%s«",
-    "Copy code block" : "Afrita kóðablokk",
+    "Set reminder for later today" : "Setja áminningu seinna í dag",
+    "Set reminder for tomorrow" : "Setja áminningu fyrir morgundaginn",
+    "Set reminder for this weekend" : "Setja áminningu fyrir þessa helgi",
+    "Set reminder for next week" : "Setja áminningu fyrir í næstu viku",
     "Today" : "Í dag",
     "Yesterday" : "Í gær",
     "_%n day ago_::_%n days ago_" : ["fyrir %n degi síðan","fyrir %n dögum síðan"],
