@@ -511,6 +511,7 @@ OC.L10N.register(
     "Assign" : "Priskirti",
     "Now" : "Dabar",
     "Unknown error occurred" : "Įvyko nežinoma klaida",
+    "Meeting" : "Susitikimas",
     "Loading …" : "Įkeliama…",
     "From" : "Nuo",
     "To" : "Kam",
@@ -528,6 +529,7 @@ OC.L10N.register(
     "This conversation is read-only" : "Šis pokalbis yra tik skaitymui",
     "Conversation not found or not joined" : "Pokalbis nerastas arba prie jo neprisijungta",
     "Connection failed" : "Ryšys patyrė nesėkmę",
+    "Reload" : "Įkelti iš naujo",
     "{nickName} raised their hand." : "{nickName} pakėlė ranką.",
     "A participant raised their hand." : "Dalyvis pakėlė ranką.",
     "Previous page of videos" : "Ankstesnis vaizdo įrašų puslapis",
@@ -568,6 +570,7 @@ OC.L10N.register(
     "Connection lost. Trying to reconnect …" : "Nutrūko ryšys. Bandoma prisijungti iš naujo…",
     "Connection problems …" : "Ryšio problemos…",
     "Collapse" : "Suskleisti",
+    "Expand" : "Išskleisti",
     "Drop your files to upload" : "Tempkite failus, norėdami juos išsiųsti",
     "Scroll to bottom" : "Slinkti į apačią",
     "Public conversation" : "Viešas pokalbis",
@@ -591,7 +594,6 @@ OC.L10N.register(
     "Restricted" : "Apribota",
     "Advanced permissions" : "Išplėstiniai leidimai",
     "Edit permissions" : "Taisyti leidimus",
-    "Meeting" : "Susitikimas",
     "Conversation settings" : "Pokalbio nustatymai",
     "Basic Info" : "Pagrindinė informacija",
     "Personal" : "Asmeniniai",
@@ -703,6 +705,8 @@ OC.L10N.register(
     "Invalid path selected" : "Pasirinktas neteisingas kelias",
     "Upload" : "Įkelti",
     "Files" : "Failai",
+    "24 hours" : "24 valandos",
+    "7 days" : "7 dienos",
     "Message text copied to clipboard" : "Žinutės tekstas nukopijuotas į iškarpinę",
     "Message text could not be copied" : "Nepavyko nukopijuoti žinutės teksto",
     "A reminder was successfully removed" : "Priminimas buvo sėkmingai pašalintas",
@@ -724,6 +728,16 @@ OC.L10N.register(
     "React with another emoji" : "Reaguoti kita šypsenėle",
     "Error while forwarding message" : "Klaida persiunčiant žinutę",
     "Dismiss" : "Atmesti",
+    "The message could not be translated" : "Nepavyko išversti laiško",
+    "Translation copied to clipboard" : "Vertimas nukopijuotas į iškarpinę",
+    "Translation could not be copied" : "Nepavyko nukopijuoti vertimo",
+    "Translate message" : "Versti laišką",
+    "Source language to translate from" : "Pradinė kalba, iš kurios versti",
+    "Translate from" : "Versti iš",
+    "Target language to translate into" : "Paskirties kalbą, į kurią versti",
+    "Translate to" : "Versti į",
+    "Translating" : "Verčiama",
+    "Send now" : "Siųsti dabar",
     "Message sent" : "Žinutė išsiųsta",
     "Message deleted successfully" : "Žinutė sėkmingai ištrinta",
     "Your browser does not support playing audio files" : "Jūsų naršyklė nepalaiko garso įrašo failų atkūrimo",
@@ -739,6 +753,7 @@ OC.L10N.register(
     "Show all reactions" : "Rodyti visas reakcijas",
     "Add more reactions" : "Pridėti daugiau reakcijų",
     "No messages" : "Nėra laiškų",
+    "Unpin" : "Atsegti",
     "Cancel search" : "Atsisakyti paieškos",
     "Add a phone number" : "Pridėti telefono numerį",
     "Create a new group conversation" : "Sukurti naują grupės pokalbį",
@@ -750,6 +765,7 @@ OC.L10N.register(
     "Send without notification" : "Siųsti be pranešimo",
     "File to share" : "Failas, kurį bendrinti",
     "Add emoji" : "Pridėti šypsenėlę",
+    "Send later" : "Siųsti vėliau",
     "Share from Files" : "Bendrinti iš failų",
     "Upload from device" : "Įkelti iš įrenginio",
     "Create new poll" : "Sukurti naują apklausą",
@@ -816,7 +832,6 @@ OC.L10N.register(
     "Search conversations or users" : "Ieškoti pokalbių ar naudotojų",
     "Phone numbers" : "Telefono numeriai",
     "Error while setting attachment folder" : "Klaida nustatant priedų aplanką",
-    "Your privacy setting has been saved" : "Jūsų privatumo nustatymas įrašytas",
     "Notification settings" : "Pranešimų nustatymai",
     "Privacy" : "Privatumas",
     "Attachments folder" : "Priedų aplankas",
@@ -910,8 +925,6 @@ OC.L10N.register(
     "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
     "Conversation link copied to clipboard" : "Pokalbio nuoroda nukopijuota į iškarpinę",
     "The link could not be copied" : "Nepavyko nukopijuoti nuorodos",
-    "Establishing signaling connection is taking longer than expected …" : "Signalinio ryšio užmezgimas trunka ilgiau nei tikėtasi…",
-    "Failed to establish signaling connection. Retrying …" : "Nepavyko užmegzti signalinio ryšio. Bandoma iš naujo…",
     "Please reload the page." : "Prašome įkelti puslapį iš naujo.",
     "Do not disturb" : "Netrukdyti",
     "Away" : "Atsitraukęs",
@@ -951,6 +964,7 @@ OC.L10N.register(
     "A week ago" : "Prieš savaitę",
     "_%n day ago_::_%n days ago_" : ["prieš %n dieną","prieš %n dienas","prieš %n dienų","prieš %n dieną"],
     "Choose the folder in which attachments should be saved." : "Pasirinkite aplanką į kurį bus įrašomi priedai.",
+    "Your privacy setting has been saved" : "Jūsų privatumo nustatymas įrašytas",
     "Choose devices" : "Pasirinkti įrenginius",
     "Browse …" : "Naršyti…",
     "Appearance" : "Išvaizda",
@@ -962,6 +976,8 @@ OC.L10N.register(
     "Blur background" : "Sulieti foną",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
     "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome."
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
+    "Establishing signaling connection is taking longer than expected …" : "Signalinio ryšio užmezgimas trunka ilgiau nei tikėtasi…",
+    "Failed to establish signaling connection. Retrying …" : "Nepavyko užmegzti signalinio ryšio. Bandoma iš naujo…"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
