@@ -582,6 +582,7 @@ OC.L10N.register(
     "Back" : "Назад",
     "Add participant \"{user}\"" : "Додади учесник \"{user}\"",
     "Now" : "Сега",
+    "Meeting" : "Средба",
     "Loading …" : "Се вчитува…",
     "From" : "Од",
     "To" : "До",
@@ -646,7 +647,6 @@ OC.L10N.register(
     "Restricted" : "Ограничена",
     "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Учесниците може да се придружуваат на повици, но не можат да овозможат аудио или видео, ниту да споделуваат екран додека модераторот рачно не им даде дозвола.",
     "Edit permissions" : "Уреди дозволи",
-    "Meeting" : "Средба",
     "Conversation settings" : "Параметри за разговор",
     "Basic Info" : "Основни информации",
     "Personal" : "Лично",
@@ -717,6 +717,7 @@ OC.L10N.register(
     "Blur" : "Замаглување",
     "Upload" : "Прикачи",
     "Files" : "Датотеки",
+    "24 hours" : "24 часа",
     "Clear reminder – {timeLocale}" : "Избришан потсетник – {timeLocale}",
     "Message text copied to clipboard" : "Пораката е копирана во клипборд",
     "A reminder was successfully removed" : "Потсетникот е успешно избришан",
@@ -735,6 +736,7 @@ OC.L10N.register(
     "Error while forwarding message" : "Грешка при препраќање на пораката",
     "The message has been forwarded to {selectedConversationName}" : "Пораката е препратена до {selectedConversationName}",
     "Dismiss" : "Отфрли",
+    "Send now" : "Испрати сега",
     "Message sent" : "Пораката е испратена",
     "Contact" : "Контакт",
     "{stack} in {board}" : "{stack} во {board}",
@@ -744,6 +746,7 @@ OC.L10N.register(
     "Poll" : "Анкета",
     "See results" : "Vidi rezultati",
     "No messages" : "Нема пораки",
+    "Unpin" : "Од-ппинувај",
     "Create a new group conversation" : "Креирајте нов групен разговор",
     "Add participants" : "Додади учесници",
     "Allow guests to join via link" : "Дозволи им на гостите да се приклучат преку линк",
@@ -752,6 +755,7 @@ OC.L10N.register(
     "Send message" : "Испрати порака",
     "File to share" : "Датотека за споделување",
     "Add emoji" : "Додади емотикон",
+    "Send later" : "Испрати покасно",
     "Cancel editing" : "Откажи уредување",
     "Share from {nextcloud}" : "Сподели од {nextcloud}",
     "Share from Files" : "Сподели од датотеките",
@@ -857,10 +861,8 @@ OC.L10N.register(
     "Save name" : "Зачувај име",
     "Select location for attachments" : "Избери локација за прилози",
     "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
-    "Your privacy setting has been saved" : "Вашите поставки за приватност се зачувани",
     "Error while setting read status privacy" : "Грешка при зачувување на поставките за приватност",
     "Failed to save sounds setting" : "Неуспешно зачувување на параметрите за звуци",
-    "Sounds setting saved" : "Параматрите за звуци се зачувани",
     "Error while saving sounds setting" : "Грешка при зачувување на параметрите за звуци",
     "Play sounds when participants join or leave a call" : "Репродуцирајте звуци кога учесниците се придружуваат или оставаат повик",
     "Notification settings" : "Параметри за известување",
@@ -1013,6 +1015,8 @@ OC.L10N.register(
     "Yesterday" : "Вчера",
     "_%n day ago_::_%n days ago_" : ["пред %n ден","пред %n дена"],
     "Choose the folder in which attachments should be saved." : "Изберете ја папката во која треба да се зачуваат прилозите.",
+    "Your privacy setting has been saved" : "Вашите поставки за приватност се зачувани",
+    "Sounds setting saved" : "Параматрите за звуци се зачувани",
     "Choose devices" : "Избери уреди",
     "Appearance" : "Изглед",
     "Share my read-status and show the read-status of others" : "Сподели го мојот статус на читање и прикажете го статусот на читање на другите",
