@@ -591,6 +591,7 @@ OC.L10N.register(
     "Cancel" : "Anullar",
     "Back" : "Retorn",
     "Add participant \"{user}\"" : "Apondre participant « {user} »",
+    "Meeting" : "Reünion",
     "Loading …" : "Cargament…",
     "From" : "De",
     "Calendar" : "Calendièr",
@@ -607,6 +608,7 @@ OC.L10N.register(
     "Speaker view" : "Vista parlaire",
     "Grid view" : "Vista en grasilha",
     "This conversation is read-only" : "Aquesta conversacion es en lectura sola",
+    "Reload" : "Recargar",
     "{nickName} raised their hand." : "{nickName} a levat la man.",
     "A participant raised their hand." : "Un participant a levat la man.",
     "Previous page of videos" : "Pagina de vidèos precedenta",
@@ -672,7 +674,6 @@ OC.L10N.register(
     "Restricted" : "Restrencha",
     "Advanced permissions" : "Permissions avançadas",
     "Edit permissions" : "Modificar las autorizacions",
-    "Meeting" : "Reünion",
     "Conversation settings" : "Paramètres de conversacion",
     "Personal" : "Personal",
     "Matterbridge" : "Matterbridge",
@@ -767,6 +768,8 @@ OC.L10N.register(
     "Invalid path selected" : "Camin seleccionat invalid",
     "Upload" : "Cargament",
     "Files" : "Fichièrs",
+    "24 hours" : "24 oras",
+    "7 days" : "7 jorns",
     "Add a reaction to this message" : "Apondre una reaccion a aqueste messatge",
     "Reply" : "Respondre",
     "More actions" : "Mai d’accions",
@@ -916,10 +919,8 @@ OC.L10N.register(
     "Save name" : "Enregistrar lo nom",
     "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
     "Error while setting attachment folder" : "Error pendent la definicion del dossièr de pèça junta",
-    "Your privacy setting has been saved" : "Paramètre de confidencialitat enregistrat",
     "Error while setting read status privacy" : "Error lor de definicion de la confidencialitat de l'estatut",
     "Failed to save sounds setting" : "Cargament impossible del paramètre de son",
-    "Sounds setting saved" : "Paramètres de son enregistrats",
     "Error while saving sounds setting" : "Error en enregistrant lo paramètre de son",
     "Play sounds when participants join or leave a call" : "Emetre sons quand los participants rejonhon o quitan una sonada",
     "Notification settings" : "Paramètres de notificacions",
@@ -1067,9 +1068,6 @@ OC.L10N.register(
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
     "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "Lost connection to signaling server. Trying to reconnect." : "Connexion perduda al servidor de senhalament. Ensag de reconnexion.",
-    "Establishing signaling connection is taking longer than expected …" : "L’establiment de la connexion de senhalizacion pren mai de temps que previst…",
-    "Failed to establish signaling connection. Retrying …" : "Fracàs de l’establiment de la connexion de senhalizacion. Novèl ensag…",
-    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Fracàs de l’establiment de la connexion de senhalizacion. Quicòm pòt èsser maridament configurat costat servidor.",
     "Please reload the page." : "Volgatz recargar la pagina.",
     "Do not disturb" : "Me desrengar pas",
     "Away" : "Absent",
@@ -1101,6 +1099,8 @@ OC.L10N.register(
     "Yesterday" : "Ièr",
     "_%n day ago_::_%n days ago_" : ["fa %n jorn","fa %n jorns"],
     "Choose the folder in which attachments should be saved." : "Causir lo dossièr ont seràn gardadas las pèça juntas.",
+    "Your privacy setting has been saved" : "Paramètre de confidencialitat enregistrat",
+    "Sounds setting saved" : "Paramètres de son enregistrats",
     "Choose devices" : "Causir periferics",
     "Browse …" : "Percórrer...",
     "Appearance" : "Aparéncia",
@@ -1112,6 +1112,9 @@ OC.L10N.register(
     "Blur background" : "Rèireplan trebol",
     "Sharing your screen only works with Firefox version 52 or newer." : "Lo partiment d’ecran fonciona pas qu’amb Firefox 52 o mai recent.",
     "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran."
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran.",
+    "Establishing signaling connection is taking longer than expected …" : "L’establiment de la connexion de senhalizacion pren mai de temps que previst…",
+    "Failed to establish signaling connection. Retrying …" : "Fracàs de l’establiment de la connexion de senhalizacion. Novèl ensag…",
+    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Fracàs de l’establiment de la connexion de senhalizacion. Quicòm pòt èsser maridament configurat costat servidor."
 },
 "nplurals=2; plural=(n > 1);");
