@@ -277,6 +277,7 @@ OC.L10N.register(
     "No results" : "Sem resultados",
     "Done" : "Concluído",
     "Grid view" : "Vista em grelha",
+    "Reload" : "Recarregar",
     "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
     "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
     "Share this link to invite others!" : "Envie este link para convidar outros!",
@@ -301,6 +302,7 @@ OC.L10N.register(
     "Delete conversation" : "Eliminar conversação",
     "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
     "_%n day_::_%n days_" : ["%n dia","%n dias","%n dias"],
+    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "As mensagens de chat podem expirar após um determinado período. Nota: os ficheiros partilhados no chat não serão eliminados para o proprietário, mas deixarão de ser partilhados na conversa.",
     "Password protection" : "Protegido por palavra-passe",
     "Set a password" : "Definir uma palavra-passe",
     "Edit" : "Editar",
@@ -314,7 +316,6 @@ OC.L10N.register(
     "Add to favorites" : "Adicionar aos favoritos",
     "Home" : "Início",
     "Clear filter" : "Limpar filtro",
-    "Talk settings" : "Definições do Falar",
     "Users" : "Utilizadores",
     "Groups" : "Grupos",
     "Teams" : "Grupos",
@@ -323,6 +324,8 @@ OC.L10N.register(
     "Blur" : "Blur",
     "Upload" : "Enviar",
     "Files" : "Ficheiros",
+    "24 hours" : "24 horas",
+    "7 days" : "7 dias",
     "Message forwarded to \"Note to self\"" : "Mensagem reencaminhada para \"Nota a mim\"",
     "Error while forwarding message to \"Note to self\"" : "Erro ao reencaminhar mensagem para \"Nota a mim\"",
     "Reply" : "Resposta",
@@ -334,6 +337,7 @@ OC.L10N.register(
     "No messages" : "Sem mensagens",
     "Create a new group conversation" : "Criar nova conversa de grupo",
     "Send message" : "Enviar mensagem",
+    "File to share" : "Ficheiro a partilhar",
     "New file" : "Ficheiro novo",
     "Send" : "Enviar",
     "Settings" : "Definições",
@@ -344,6 +348,7 @@ OC.L10N.register(
     "Promote to moderator" : "Promover a moderador",
     "Remove" : "Remover",
     "Add users or groups" : "Add users or groups",
+    "Add users" : "Adicionar utilizadores",
     "Integrations" : "Integrações",
     "Searching …" : "À procura …",
     "Participants" : "Participantes",
@@ -354,6 +359,7 @@ OC.L10N.register(
     "Load more results" : "Mostrar mais resultados",
     "Projects" : "Projectos",
     "No shared items" : "Sem itens partilhados",
+    "Appearance & Sounds" : "Aspeto e sons",
     "Notification settings" : "Definições de notificação",
     "Privacy" : "Privacidade",
     "Search" : "Pesquisa sobre",
@@ -394,9 +400,11 @@ OC.L10N.register(
     "Tasks" : "Tarefas",
     "Notes" : "Notas",
     "Reports" : "Relatórios",
+    "Talk settings" : "Definições do Falar",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
     "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
+    "Appearance" : "Aspeto",
     "Performance" : "Performance",
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
