@@ -604,6 +604,7 @@ OC.L10N.register(
     "Cancel" : "Annulla",
     "Back" : "In segus",
     "Add participant \"{user}\"" : "Agiunghe partetzipante \"{user}\"",
+    "Meeting" : "Atòbiu",
     "Loading …" : "Carrigamentu …",
     "From" : "Dae",
     "To" : "A",
@@ -619,6 +620,7 @@ OC.L10N.register(
     "Speaker view" : "Bista de sa persone chi faeddat",
     "Grid view" : "Bisione grìllia",
     "This conversation is read-only" : "Custa resonada est de letura sola",
+    "Reload" : "Torra a carrigare",
     "{nickName} raised their hand." : "{nickName} ant artziadu sa manu",
     "A participant raised their hand." : "Una persona at artziadu sa manu",
     "Collapse stripe" : "Istringhe sa tira",
@@ -670,7 +672,6 @@ OC.L10N.register(
     "The file must be a PNG or JPG" : "S'archìviu depet èssere unu PNG o JPG",
     "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Ogni borta chi is permissos sunt modificados in custa setzione, is permissos personalizados assignados in pretzedèntzia a partetzipantes individuales ant a èssere pèrdidos.",
     "Restricted" : "Limitadu",
-    "Meeting" : "Atòbiu",
     "Conversation settings" : "Cunfiguratzione de sa resonada",
     "Personal" : "Personale",
     "Matterbridge" : "Matterbridge",
@@ -768,6 +769,7 @@ OC.L10N.register(
     "Invalid path selected" : "Percursu seletzionadu non bàlidu",
     "Upload" : "Càrriga",
     "Files" : "Archìvios",
+    "24 hours" : "24 oras",
     "A reminder was successfully set at {datetime}" : "Apuntu cunfiguradu pro {datetime}",
     "Reply" : "Risponde",
     "More actions" : "Àteras atziones",
@@ -801,6 +803,7 @@ OC.L10N.register(
     "You are not allowed to share files" : "Non tenes su permissu de cumpartzire archìvios",
     "You cannot send messages to this conversation at the moment" : "Non podes imbiare messàgios in custa resonada in custu momentu",
     "No messages" : "Perunu messàgiu",
+    "Unpin" : "No apicare",
     "Create a new group conversation" : "Crea unu grupu de resonada nou",
     "Add participants" : "Agiunghe partetzipantes",
     "Allow guests to join via link" : "Permite a is persones invitadas de intrare cun unu ligòngiu",
@@ -875,10 +878,8 @@ OC.L10N.register(
     "Select conversation" : "Seletziona resonada",
     "Select location for attachments" : "Seletziona sa positzione pro is alligongiados",
     "Error while setting attachment folder" : "Errore in sa cunfiguratzione de sa cartella de is alligongiados",
-    "Your privacy setting has been saved" : "Sa cunfiguratzione de riservadesa tua est istada sarvada",
     "Error while setting read status privacy" : "Errore in sa cunfiguratzione de sa riservadesa de s'istadu de letura",
     "Failed to save sounds setting" : "Non at fatu a sarvare sa cunfiguratzione de is sonos",
-    "Sounds setting saved" : "Cunfiguratzione de is sonos sarvada",
     "Error while saving sounds setting" : "Errore sarvende sa cunfiguratzione de is sonos",
     "Play sounds when participants join or leave a call" : "Ativa is sonos cando is partetzipantes intrant o lassant una mutida",
     "Notification settings" : "Cunfiguratzione de notìficas",
@@ -1004,9 +1005,6 @@ OC.L10N.register(
     "Error occurred when sending invitations" : "B'at àpidu un'errore imbiende is invitos",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Su navigadore chi ses impreende no est suportadu totu dae Nextcloud. Imprea s'ùrtima versione de Mozilla Firefox, Microsoft Edge, Google Chrome, Opera o Apple Safari.",
     "Lost connection to signaling server. Trying to reconnect." : "Connessione pèrdida cun su serbidore de signalatzione. Proende a torrare a connètere",
-    "Establishing signaling connection is taking longer than expected …" : "Sa creatzione de sa connessione de signalatzione est istentende prus de su tempus prevìdidu ...",
-    "Failed to establish signaling connection. Retrying …" : "No at fatu a creare sa connessione de signalatzione. Torrende a proare ... ",
-    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "No at fatu a creare sa connessione de signalatzione. B'at calicuna cosa isballiada in sa cunfiguratzione de su serbidore de signalatzione",
     "Please reload the page." : "Torra a carrigare sa pàgina.",
     "Do not disturb" : "No istorbes",
     "Away" : "Foras",
@@ -1044,6 +1042,8 @@ OC.L10N.register(
     "Yesterday" : "Eris",
     "_%n day ago_::_%n days ago_" : ["%n dies a oe","%n dies a oe"],
     "Choose the folder in which attachments should be saved." : "Sèbera in cale cartella depent èssere sarvados is alligongiados.",
+    "Your privacy setting has been saved" : "Sa cunfiguratzione de riservadesa tua est istada sarvada",
+    "Sounds setting saved" : "Cunfiguratzione de is sonos sarvada",
     "Choose devices" : "Sèbera dispositivos",
     "Appearance" : "Aspetu",
     "Share my read-status and show the read-status of others" : "Cumpartzi s'istadu de letura miu e mustra cussu de àtere",
@@ -1055,6 +1055,9 @@ OC.L10N.register(
     "Space bar" : "Istanca de logu",
     "Sharing your screen only works with Firefox version 52 or newer." : "Podes cumpartzire s'ischermu isceti cun Firefox versione 52 o prus noa.",
     "Screensharing extension is required to share your screen." : "Pro cumpartzire s'ischermu serbit un'estensione de Screensharing.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Imprea un'àteru navigadore comente Firefox o Chrome pro cumpartzire s'ischermu."
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Imprea un'àteru navigadore comente Firefox o Chrome pro cumpartzire s'ischermu.",
+    "Establishing signaling connection is taking longer than expected …" : "Sa creatzione de sa connessione de signalatzione est istentende prus de su tempus prevìdidu ...",
+    "Failed to establish signaling connection. Retrying …" : "No at fatu a creare sa connessione de signalatzione. Torrende a proare ... ",
+    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "No at fatu a creare sa connessione de signalatzione. B'at calicuna cosa isballiada in sa cunfiguratzione de su serbidore de signalatzione"
 },
 "nplurals=2; plural=(n != 1);");
