@@ -11,19 +11,18 @@ namespace OCA\Talk\Chat\AutoComplete;
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Chat\CommentsManager;
 use OCP\Collaboration\AutoComplete\ISorter;
-use OCP\Comments\ICommentsManager;
 
 class Sorter implements ISorter {
-	protected ICommentsManager $commentsManager;
-
-	public function __construct(CommentsManager $commentsManager) {
-		$this->commentsManager = $commentsManager;
+	public function __construct(
+		protected CommentsManager $commentsManager,
+	) {
 	}
 
 	/**
 	 * @return string The ID of the sorter, e.g. commenters
 	 * @since 13.0.0
 	 */
+	#[\Override]
 	public function getId(): string {
 		return 'talk_chat_participants';
 	}
@@ -32,9 +31,10 @@ class Sorter implements ISorter {
 	 * executes the sort action
 	 *
 	 * @param array $sortArray the array to be sorted, provided as reference
-	 * @param array{itemType: string, itemId: string, search?: string} $context carries key 'itemType' and 'itemId' of the source object (e.g. a file)
+	 * @param array{itemType: string, itemId: string, search?: string, selfUserId?: ?string, selfCloudId?: ?string} $context carries key 'itemType' and 'itemId' of the source object (e.g. a file)
 	 * @since 13.0.0
 	 */
+	#[\Override]
 	public function sort(array &$sortArray, array $context): void {
 		foreach ($sortArray as $type => &$byType) {
 			if ($type !== 'users') {
@@ -52,8 +52,16 @@ class Sorter implements ISorter {
 				}, $byType));
 
 			$search = $context['search'];
+			$selfUserId = $context['selfUserId'] ?? null;
+
+			usort($byType, static function (array $a, array $b) use ($lastComments, $search, $selfUserId) {
+				if ($selfUserId === $a['value']['shareWith']) {
+					return 1;
+				}
+				if ($selfUserId === $b['value']['shareWith']) {
+					return -1;
+				}
 
-			usort($byType, function (array $a, array $b) use ($lastComments, $search) {
 				if ($search) {
 					// If the user searched for "Dani" we make sure "Daniel" comes before "Madani"
 					if (stripos($a['label'], $search) === 0) {
