@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @author Joachim Bauch <mail@joachim-bauch.de>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Collaboration\Collaborators;
@@ -33,57 +18,46 @@ use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\TalkSession;
-use OCP\Collaboration\AutoComplete\AutoCompleteEvent;
-use OCP\Collaboration\AutoComplete\IManager;
-use OCP\EventDispatcher\IEventDispatcher;
+use OCP\Collaboration\AutoComplete\AutoCompleteFilterEvent;
+use OCP\EventDispatcher\Event;
+use OCP\EventDispatcher\IEventListener;
 use OCP\IUser;
 use OCP\IUserManager;
-use OCP\Server;
 
-class Listener {
-	protected Manager $manager;
-	protected IUserManager $userManager;
-	protected ParticipantService $participantService;
-	protected Config $config;
-	protected TalkSession $talkSession;
+/**
+ * @template-implements IEventListener<Event>
+ */
+class Listener implements IEventListener {
 	/** @var string[] */
 	protected array $allowedGroupIds = [];
 	protected string $roomToken;
 	protected ?Room $room = null;
-	protected ?string $userId;
 
 	public function __construct(
-		Manager $manager,
-		IUserManager $userManager,
-		ParticipantService $participantService,
-		Config $config,
-		TalkSession $talkSession,
-		?string $userId,
+		protected Manager $manager,
+		protected IUserManager $userManager,
+		protected ParticipantService $participantService,
+		protected Config $config,
+		protected TalkSession $talkSession,
+		protected ?string $userId,
 	) {
-		$this->manager = $manager;
-		$this->userManager = $userManager;
-		$this->participantService = $participantService;
-		$this->talkSession = $talkSession;
-		$this->config = $config;
-		$this->userId = $userId;
 	}
 
-	public static function register(IEventDispatcher $dispatcher): void {
-		$dispatcher->addListener(IManager::class . '::filterResults', [self::class, 'filterNonListableMesssages']);
-	}
-
-	public static function filterNonListableMesssages(AutoCompleteEvent $event): void {
-		$listener = Server::get(self::class);
+	#[\Override]
+	public function handle(Event $event): void {
+		if (!$event instanceof AutoCompleteFilterEvent) {
+			return;
+		}
 
 		if ($event->getItemType() !== 'call') {
 			return;
 		}
 
-		$event->setResults($listener->filterUsersAndGroupsWithoutTalk($event->getResults()));
+		$event->setResults($this->filterUsersAndGroupsWithoutTalk($event->getResults()));
 
-		$event->setResults($listener->filterBridgeBot($event->getResults()));
+		$event->setResults($this->filterBridgeBot($event->getResults()));
 		if ($event->getItemId() !== 'new') {
-			$event->setResults($listener->filterExistingParticipants($event->getItemId(), $event->getResults()));
+			$event->setResults($this->filterExistingParticipants($event->getItemId(), $event->getResults()));
 		}
 	}
 
@@ -139,9 +113,11 @@ class Listener {
 			} else {
 				$this->participantService->getParticipantBySession($this->room, $sessionId);
 			}
-		} catch (RoomNotFoundException $e) {
+		} catch (RoomNotFoundException|ParticipantNotFoundException) {
 			return $results;
-		} catch (ParticipantNotFoundException $e) {
+		}
+
+		if ($this->room->isFederatedConversation()) {
 			return $results;
 		}
 
@@ -159,6 +135,13 @@ class Listener {
 			$results['exact']['users'] = array_filter($results['exact']['users'], [$this, 'filterParticipantUserResult']);
 		}
 
+		if (!empty($results['circles'])) {
+			$results['circles'] = array_filter($results['circles'], [$this, 'filterParticipantTeamResult']);
+		}
+		if (!empty($results['exact']['circles'])) {
+			$results['exact']['circles'] = array_filter($results['exact']['circles'], [$this, 'filterParticipantTeamResult']);
+		}
+
 		return $results;
 	}
 
@@ -191,4 +174,15 @@ class Listener {
 			return true;
 		}
 	}
+
+	protected function filterParticipantTeamResult(array $result): bool {
+		$circleId = $result['value']['shareWith'];
+
+		try {
+			$this->participantService->getParticipantByActor($this->room, Attendee::ACTOR_CIRCLES, $circleId);
+			return false;
+		} catch (ParticipantNotFoundException $e) {
+			return true;
+		}
+	}
 }
