@@ -18,21 +18,24 @@ use OCP\SetupCheck\SetupResult;
 
 class FederationLockCache implements ISetupCheck {
 	public function __construct(
-		readonly protected Config $talkConfig,
-		readonly protected ICacheFactory $cacheFactory,
-		readonly protected IURLGenerator $urlGenerator,
-		readonly protected IL10N $l,
+		protected readonly Config $talkConfig,
+		protected readonly ICacheFactory $cacheFactory,
+		protected readonly IURLGenerator $urlGenerator,
+		protected readonly IL10N $l,
 	) {
 	}
 
+	#[\Override]
 	public function getCategory(): string {
 		return 'talk';
 	}
 
+	#[\Override]
 	public function getName(): string {
 		return $this->l->t('Federation');
 	}
 
+	#[\Override]
 	public function run(): SetupResult {
 		if (!$this->talkConfig->isFederationEnabled()) {
 			return SetupResult::success();
